# 0.0.4

## 新特性

+ 增加参数`json_render_kws`用于设置json的输出格式

# 0.0.3

## 优化

+ 去掉了`logger`这个意义不明的字段,改为使用`app_name`
+ `timestamp`改为`time`避免歧义

# 0.0.2

## 新特性

+ 怎加了初始化参数`binds:Dict[str,Any]`用于绑定固定字段

# 0.0.1

项目创建